==> nextcloud-29.0.12.tgz: nextcloud/apps/weather_status/l10n/lv.js <==
OC.L10N.register(
    "weather_status",
    {
    "Unknown address" : "Nezināma adrese",
    "No result." : "Nav iznākuma.",
    "Malformed JSON data." : "Nepareizi veidoti JSON dati.",
    "Error" : "Kļūda",
    "Weather status" : "Laikapstākļu stāvoklis",
    "Weather status in your dashboard" : "Laikapstākļu stāvoklis informācijas panelī",
    "Weather status integrated in the Dashboard app.\n    The geographic location can be automatically determined or manually defined. A 6 hours forecast is then displayed.\n    This status can also be integrated in other places like the Calendar app." : "Laikapstākļu stāvoklis iekļauts informācijas paneļa lietotnē.\nĢeogrāfiskā atrašanās vieta var tikt automātiski noteikta vai pašrocīgi norādīta. Tad tiek attēlota 6 stundu prognoze.\nŠis stāvoklis var tikt ievietots arī citās vietās, piemēram, kalendāra lietotnē.",
    "Detect location" : "Noteikt atrašanās vietu",
    "Set custom address" : "Iestatīt pielāgotu adresi",
    "Favorites" : "Izlase",
    "{temperature} {unit} clear sky later today" : "{temperature} {unit} skaidras debesis vēlāk šodien",
    "{temperature} {unit} clear sky" : "{temperature} {unit} skaidras debesis",
    "{temperature} {unit} cloudy later today" : "{temperature} {unit} mākoņains vēlāk šodien",
    "{temperature} {unit} cloudy" : "{temperature} {unit} mākoņains",
    "{temperature} {unit} snow and thunder later today" : "{temperature} {unit} sniegs un pērkons vēlāk šodien",
    "{temperature} {unit} snow and thunder" : "{temperature} {unit} sniegs un pērkons",
    "{temperature} {unit} snow showers and thunder later today" : "{temperature} {unit} sniega brāzmas un pērkons vēlāk šodien",
    "{temperature} {unit} snow showers and thunder" : "{temperature} {unit} sniega brāzmas un pērkons",
    "{temperature} {unit} snow showers, thunder and polar twilight later today" : "{temperature} {unit} sniega brāzmas, pērkons un polārā krēsla vēlāk šodien",
    "{temperature} {unit} snow showers, thunder and polar twilight" : "{temperature} {unit} sniega brāzmas, pērkons un polārā krēsla",
    "{temperature} {unit} snow showers later today" : "{temperature} {unit} sniega brāzmas vēlāk šodien",
    "{temperature} {unit} snow showers" : "{temperature} {unit} sniega brāzmas",
    "{temperature} {unit} snow showers and polar twilight later today" : "{temperature} {unit} sniega brāzmas un polārā krēsla vēlāk šodien",
    "{temperature} {unit} snow showers and polar twilight" : "{temperature} {unit} sniega brāzmas un polārā krēsla",
    "{temperature} {unit} snow later today" : "{temperature} {unit} sniegs vēlāk šodien",
    "{temperature} {unit} snow" : "{temperature} {unit} sniegs",
    "{temperature} {unit} fair weather later today" : "{temperature} {unit} labi laikapstākļi vēlāk šodien",
    "{temperature} {unit} fair weather" : "{temperature} {unit} labi laikapstākļi",
    "{temperature} {unit} partly cloudy later today" : "{temperature} {unit} daļēji mākoņains vēlāk šodien",
    "{temperature} {unit} partly cloudy" : "{temperature} {unit} daļēji mākoņains",
    "{temperature} {unit} foggy later today" : "{temperature} {unit} miglains vēlāk šodien",
    "{temperature} {unit} foggy" : "{temperature} {unit} miglains",
    "{temperature} {unit} light rainfall later today" : "{temperature} {unit} viegli nokrišņi vēlāk šodien",
    "{temperature} {unit} light rainfall" : "{temperature} {unit} viegli nokrišņi",
    "{temperature} {unit} rainfall later today" : "{temperature} {unit} nokrišņi vēlāk šodien",
    "{temperature} {unit} rainfall" : "{temperature} {unit} nokrišņi",
    "{temperature} {unit} heavy rainfall later today" : "{temperature} {unit} spēcīgi nokrišņi vēlāk šodien",
    "{temperature} {unit} heavy rainfall" : "{temperature} {unit} spēcīgi nokrišņi",
    "{temperature} {unit} rainfall showers later today" : "{temperature} {unit} nokrišņu brāzmas vēlāk šodien",
    "{temperature} {unit} rainfall showers" : "{temperature} {unit} nokrišņu brāzmas",
    "{temperature} {unit} light rainfall showers later today" : "{temperature} {unit} vieglas nokrišņu brāzmas vēlāk šodien",
    "{temperature} {unit} light rainfall showers" : "{temperature} {unit} vieglas nokrišņu brāzmas",
    "{temperature} {unit} heavy rainfall showers later today" : "{temperature} {unit} spēcīgas nokrišņu brāzmas vēlāk šodien",
    "{temperature} {unit} heavy rainfall showers" : "{temperature} {unit} spēcīgas nokrišņu brāzmas",
    "More weather for {adr}" : "Vairāk laikapstākļu datu par {adr}",
    "Loading weather" : "Ielādē laikapstākļus",
    "Set location for weather" : "Iestatīt atrašanās vietu laikapstākļiem",
    "Remove from favorites" : "Noņemt no izlases",
    "Add as favorite" : "Pievienot izlasei",
    "You are not logged in." : "Tu neesi pieteicies.",
    "There was an error getting the weather status information." : "Atgadījās kļūda laikapstākļu stāvokļa informācijas iegūšanā.",
    "No weather information found" : "Netika atrasta informācija par laikapstākļiem",
    "Location not found" : "Atrašanās vieta nav atrasta",
    "There was an error setting the location address." : "Atgadījās kļūda atrašanās vietas adreses iestatīšanā.",
    "There was an error setting the location." : "Atgadījās kļūda atrašanās vietas iestatīšanā.",
    "There was an error saving the mode." : "Atgadījās kļūda režīma saglabāšanā.",
    "There was an error using personal address." : "Atgadījās kļūda personīgās adreses izmantošanā.",
    "Unknown weather code" : "Nezināms laikapstākļu kods"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n != 0 ? 1 : 2);");

==> nextcloud-30.0.5.tgz: nextcloud/apps/weather_status/l10n/lv.js <==
OC.L10N.register(
    "weather_status",
    {
    "Unknown address" : "Nezināma adrese",
    "No result." : "Nav iznākuma.",
    "Malformed JSON data." : "Nepareizi veidoti JSON dati.",
    "Error" : "Kļūda",
    "Weather status" : "Laikapstākļu stāvoklis",
    "Weather status in your dashboard" : "Laikapstākļu stāvoklis informācijas panelī",
    "Weather status integrated in the Dashboard app.\n    The geographic location can be automatically determined or manually defined. A 6 hours forecast is then displayed.\n    This status can also be integrated in other places like the Calendar app." : "Laikapstākļu stāvoklis iekļauts informācijas paneļa lietotnē.\nĢeogrāfiskā atrašanās vieta var tikt automātiski noteikta vai pašrocīgi norādīta. Tad tiek attēlota 6 stundu prognoze.\nŠis stāvoklis var tikt ievietots arī citās vietās, piemēram, kalendāra lietotnē.",
    "Detect location" : "Noteikt atrašanās vietu",
    "Set custom address" : "Iestatīt pielāgotu adresi",
    "Favorites" : "Izlase",
    "{temperature} {unit} clear sky later today" : "{temperature} {unit} skaidras debesis vēlāk šodien",
    "{temperature} {unit} clear sky" : "{temperature} {unit} skaidras debesis",
    "{temperature} {unit} cloudy later today" : "{temperature} {unit} mākoņains vēlāk šodien",
    "{temperature} {unit} cloudy" : "{temperature} {unit} mākoņains",
    "{temperature} {unit} snow and thunder later today" : "{temperature} {unit} sniegs un pērkons vēlāk šodien",
    "{temperature} {unit} snow and thunder" : "{temperature} {unit} sniegs un pērkons",
    "{temperature} {unit} snow showers and thunder later today" : "{temperature} {unit} sniega brāzmas un pērkons vēlāk šodien",
    "{temperature} {unit} snow showers and thunder" : "{temperature} {unit} sniega brāzmas un pērkons",
    "{temperature} {unit} snow showers, thunder and polar twilight later today" : "{temperature} {unit} sniega brāzmas, pērkons un polārā krēsla vēlāk šodien",
    "{temperature} {unit} snow showers, thunder and polar twilight" : "{temperature} {unit} sniega brāzmas, pērkons un polārā krēsla",
    "{temperature} {unit} snow showers later today" : "{temperature} {unit} sniega brāzmas vēlāk šodien",
    "{temperature} {unit} snow showers" : "{temperature} {unit} sniega brāzmas",
    "{temperature} {unit} snow showers and polar twilight later today" : "{temperature} {unit} sniega brāzmas un polārā krēsla vēlāk šodien",
    "{temperature} {unit} snow showers and polar twilight" : "{temperature} {unit} sniega brāzmas un polārā krēsla",
    "{temperature} {unit} snow later today" : "{temperature} {unit} sniegs vēlāk šodien",
    "{temperature} {unit} snow" : "{temperature} {unit} sniegs",
    "{temperature} {unit} fair weather later today" : "{temperature} {unit} labi laikapstākļi vēlāk šodien",
    "{temperature} {unit} fair weather" : "{temperature} {unit} labi laikapstākļi",
    "{temperature} {unit} partly cloudy later today" : "{temperature} {unit} daļēji mākoņains vēlāk šodien",
    "{temperature} {unit} partly cloudy" : "{temperature} {unit} daļēji mākoņains",
    "{temperature} {unit} foggy later today" : "{temperature} {unit} miglains vēlāk šodien",
    "{temperature} {unit} foggy" : "{temperature} {unit} miglains",
    "{temperature} {unit} light rainfall later today" : "{temperature} {unit} viegli nokrišņi vēlāk šodien",
    "{temperature} {unit} light rainfall" : "{temperature} {unit} viegli nokrišņi",
    "{temperature} {unit} rainfall later today" : "{temperature} {unit} nokrišņi vēlāk šodien",
    "{temperature} {unit} rainfall" : "{temperature} {unit} nokrišņi",
    "{temperature} {unit} heavy rainfall later today" : "{temperature} {unit} spēcīgi nokrišņi vēlāk šodien",
    "{temperature} {unit} heavy rainfall" : "{temperature} {unit} spēcīgi nokrišņi",
    "{temperature} {unit} rainfall showers later today" : "{temperature} {unit} nokrišņu brāzmas vēlāk šodien",
    "{temperature} {unit} rainfall showers" : "{temperature} {unit} nokrišņu brāzmas",
    "{temperature} {unit} light rainfall showers later today" : "{temperature} {unit} vieglas nokrišņu brāzmas vēlāk šodien",
    "{temperature} {unit} light rainfall showers" : "{temperature} {unit} vieglas nokrišņu brāzmas",
    "{temperature} {unit} heavy rainfall showers later today" : "{temperature} {unit} spēcīgas nokrišņu brāzmas vēlāk šodien",
    "{temperature} {unit} heavy rainfall showers" : "{temperature} {unit} spēcīgas nokrišņu brāzmas",
    "More weather for {adr}" : "Vairāk laikapstākļu datu par {adr}",
    "Loading weather" : "Ielādē laikapstākļus",
    "Set location for weather" : "Iestatīt atrašanās vietu laikapstākļiem",
    "Remove from favorites" : "Noņemt no izlases",
    "Add as favorite" : "Pievienot izlasei",
    "You are not logged in." : "Tu neesi pieteicies.",
    "There was an error getting the weather status information." : "Atgadījās kļūda laikapstākļu stāvokļa informācijas iegūšanā.",
    "No weather information found" : "Netika atrasta informācija par laikapstākļiem",
    "Location not found" : "Atrašanās vieta nav atrasta",
    "There was an error setting the location address." : "Atgadījās kļūda atrašanās vietas adreses iestatīšanā.",
    "There was an error setting the location." : "Atgadījās kļūda atrašanās vietas iestatīšanā.",
    "There was an error saving the mode." : "Atgadījās kļūda režīma saglabāšanā.",
    "There was an error using personal address." : "Atgadījās kļūda personīgās adreses izmantošanā.",
    "Unknown weather code" : "Nezināms laikapstākļu kods",
    "Weather status integrated in the Dashboard app.\n    User's position can be automatically determined or manually defined. A 6 hours forecast is then displayed.\n    This status can also be integrated in other places like the Calendar app." : "Laikapstākļu stāvoklis iekļauts informācijas paneļa lietotnē.\nLietotāja atrašanās vieta var tikt automātiski noteikta vai pašrocīgi norādīta. Tad tiek attēlota 6 stundu prognoze.\nŠis stāvoklis var tikt ievietots arī citās vietās, piemēram, kalendāra lietotnē."
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n != 0 ? 1 : 2);");
